@@ -17,6 +17,6 @@
 #define FREERDP_VENDOR_STRING "FreeRDP"
 #define FREERDP_PRODUCT_STRING "FreeRDP"
 
-#define FREERDP_PROXY_PLUGINDIR "/build/tmp/pobj/freerdp-2.11.6/build-i386/server/proxy/plugins"
+#define FREERDP_PROXY_PLUGINDIR "/usr/obj/ports/freerdp-2.11.7/build-arm/server/proxy/plugins"
 
 #endif /* FREERDP_BUILD_CONFIG_H */
