@@ -62,6 +62,7 @@
 #define BRETON 0x047E
 #define BULGARIAN 0x0402
 #define CATALAN 0x0403
+#define CHEROKEE 0x045C
 #define CHINESE_TAIWAN 0x0404
 #define CHINESE_PRC 0x0804
 #define CHINESE_HONG_KONG 0x0C04
@@ -113,12 +114,14 @@
 #define GREEK 0x0408
 #define GREENLANDIC 0x046F
 #define GUJARATI 0x0447
+#define HAWAIIAN 0x0475
 #define HEBREW 0x040D
 #define HINDI 0x0439
 #define HUNGARIAN 0x040E
 #define ICELANDIC 0x040F
 #define IGBO 0x0470
 #define INDONESIAN 0x0421
+#define INUKTITUT 0x045D
 #define IRISH 0x083C
 #define ITALIAN_STANDARD 0x0410
 #define ITALIAN_SWISS 0x0810
@@ -146,6 +149,7 @@
 #define MARATHI 0x044E
 #define MOHAWK 0x047C
 #define MONGOLIAN 0x0450
+#define MYANMAR 0x0455
 #define NEPALI 0x0461
 #define NORWEGIAN_BOKMAL 0x0414
 #define NORWEGIAN_NYNORSK 0x0814
