@@ -135,14 +135,19 @@ enum SPI_MASK
 #endif
 
 /* Client Information PDU */
-#define TS_RAIL_CLIENTSTATUS_ALLOWLOCALMOVESIZE 0x00000001
-#define TS_RAIL_CLIENTSTATUS_AUTORECONNECT 0x00000002
-#define TS_RAIL_CLIENTSTATUS_ZORDER_SYNC 0x00000004
-#define TS_RAIL_CLIENTSTATUS_WINDOW_RESIZE_MARGIN_SUPPORTED 0x00000010
-#define TS_RAIL_CLIENTSTATUS_HIGH_DPI_ICONS_SUPPORTED 0x00000020
-#define TS_RAIL_CLIENTSTATUS_APPBAR_REMOTING_SUPPORTED 0x00000040
-#define TS_RAIL_CLIENTSTATUS_POWER_DISPLAY_REQUEST_SUPPORTED 0x00000080
-#define TS_RAIL_CLIENTSTATUS_BIDIRECTIONAL_CLOAK_SUPPORTED 0x00000200
+typedef enum
+{
+	TS_RAIL_CLIENTSTATUS_ALLOWLOCALMOVESIZE = 0x00000001,
+	TS_RAIL_CLIENTSTATUS_AUTORECONNECT = 0x00000002,
+	TS_RAIL_CLIENTSTATUS_ZORDER_SYNC = 0x00000004,
+	TS_RAIL_CLIENTSTATUS_WINDOW_RESIZE_MARGIN_SUPPORTED = 0x00000010,
+	TS_RAIL_CLIENTSTATUS_HIGH_DPI_ICONS_SUPPORTED = 0x00000020,
+	TS_RAIL_CLIENTSTATUS_APPBAR_REMOTING_SUPPORTED = 0x00000040,
+	TS_RAIL_CLIENTSTATUS_POWER_DISPLAY_REQUEST_SUPPORTED = 0x00000080,
+	TS_RAIL_CLIENTSTATUS_GET_APPID_RESPONSE_EX_SUPPORTED = 0x00000100,
+	TS_RAIL_CLIENTSTATUS_BIDIRECTIONAL_CLOAK_SUPPORTED = 0x00000200,
+	TS_RAIL_CLIENTSTATUS_SUPPRESS_ICON_ORDERS = 0x00000400
+} CLIENT_INFO_PDU;
 
 /* Server Move/Size Start PDU */
 #define RAIL_WMSZ_LEFT 0x0001
@@ -181,10 +186,15 @@ enum SPI_MASK
 #endif
 
 /* Extended Handshake Flags */
-#define TS_RAIL_ORDER_HANDSHAKEEX_FLAGS_HIDEF 0x00000001
-#define TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_EXTENDED_SPI_SUPPORTED 0x00000002
-#define TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_SNAP_ARRANGE_SUPPORTED 0x00000004
-
+typedef enum
+{
+	TS_RAIL_ORDER_HANDSHAKEEX_FLAGS_HIDEF = 0x00000001,
+	TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_EXTENDED_SPI_SUPPORTED = 0x00000002,
+	TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_SNAP_ARRANGE_SUPPORTED = 0x00000004,
+	TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_TEXT_SCALE_SUPPORTED = 0x00000008,
+	TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_CARET_BLINK_SUPPORTED = 0x00000010,
+	TS_RAIL_ORDER_HANDSHAKE_EX_FLAGS_EXTENDED_SPI_2_SUPPORTED = 0x00000020
+} EXTENDED_HANDSHAKE_FLAGS;
 /* Language Profile Information Flags */
 #define TF_PROFILETYPE_INPUTPROCESSOR 0x00000001
 #define TF_PROFILETYPE_KEYBOARDLAYOUT 0x00000002
@@ -559,30 +569,35 @@ typedef struct _RAIL_GET_APPID_RESP_EX RAIL_GET_APPID_RESP_EX;
 
 /* RAIL Constants */
 
-#define TS_RAIL_ORDER_EXEC 0x0001
-#define TS_RAIL_ORDER_ACTIVATE 0x0002
-#define TS_RAIL_ORDER_SYSPARAM 0x0003
-#define TS_RAIL_ORDER_SYSCOMMAND 0x0004
-#define TS_RAIL_ORDER_HANDSHAKE 0x0005
-#define TS_RAIL_ORDER_NOTIFY_EVENT 0x0006
-#define TS_RAIL_ORDER_WINDOWMOVE 0x0008
-#define TS_RAIL_ORDER_LOCALMOVESIZE 0x0009
-#define TS_RAIL_ORDER_MINMAXINFO 0x000A
-#define TS_RAIL_ORDER_CLIENTSTATUS 0x000B
-#define TS_RAIL_ORDER_SYSMENU 0x000C
-#define TS_RAIL_ORDER_LANGBARINFO 0x000D
-#define TS_RAIL_ORDER_GET_APPID_REQ 0x000E
-#define TS_RAIL_ORDER_GET_APPID_RESP 0x000F
-#define TS_RAIL_ORDER_TASKBARINFO 0x0010
-#define TS_RAIL_ORDER_LANGUAGEIMEINFO 0x0011
-#define TS_RAIL_ORDER_COMPARTMENTINFO 0x0012
-#define TS_RAIL_ORDER_HANDSHAKE_EX 0x0013
-#define TS_RAIL_ORDER_ZORDER_SYNC 0x0014
-#define TS_RAIL_ORDER_CLOAK 0x0015
-#define TS_RAIL_ORDER_POWER_DISPLAY_REQUEST 0x0016
-#define TS_RAIL_ORDER_SNAP_ARRANGE 0x0017
-#define TS_RAIL_ORDER_GET_APPID_RESP_EX 0x0018
-#define TS_RAIL_ORDER_EXEC_RESULT 0x0080
+typedef enum
+{
+	TS_RAIL_ORDER_EXEC = 0x0001,
+	TS_RAIL_ORDER_ACTIVATE = 0x0002,
+	TS_RAIL_ORDER_SYSPARAM = 0x0003,
+	TS_RAIL_ORDER_SYSCOMMAND = 0x0004,
+	TS_RAIL_ORDER_HANDSHAKE = 0x0005,
+	TS_RAIL_ORDER_NOTIFY_EVENT = 0x0006,
+	TS_RAIL_ORDER_WINDOWMOVE = 0x0008,
+	TS_RAIL_ORDER_LOCALMOVESIZE = 0x0009,
+	TS_RAIL_ORDER_MINMAXINFO = 0x000A,
+	TS_RAIL_ORDER_CLIENTSTATUS = 0x000B,
+	TS_RAIL_ORDER_SYSMENU = 0x000C,
+	TS_RAIL_ORDER_LANGBARINFO = 0x000D,
+	TS_RAIL_ORDER_GET_APPID_REQ = 0x000E,
+	TS_RAIL_ORDER_GET_APPID_RESP = 0x000F,
+	TS_RAIL_ORDER_TASKBARINFO = 0x0010,
+	TS_RAIL_ORDER_LANGUAGEIMEINFO = 0x0011,
+	TS_RAIL_ORDER_COMPARTMENTINFO = 0x0012,
+	TS_RAIL_ORDER_HANDSHAKE_EX = 0x0013,
+	TS_RAIL_ORDER_ZORDER_SYNC = 0x0014,
+	TS_RAIL_ORDER_CLOAK = 0x0015,
+	TS_RAIL_ORDER_POWER_DISPLAY_REQUEST = 0x0016,
+	TS_RAIL_ORDER_SNAP_ARRANGE = 0x0017,
+	TS_RAIL_ORDER_GET_APPID_RESP_EX = 0x0018,
+	TS_RAIL_ORDER_TEXTSCALEINFO = 0x0019,
+	TS_RAIL_ORDER_CARETBLINKINFO = 0x001A,
+	TS_RAIL_ORDER_EXEC_RESULT = 0x0080
+} ORDER_TYPE;
 
 #ifdef __cplusplus
 extern "C"
